@@ -3,9 +3,11 @@ Main interface for ec2-instance-connect service type definitions.
 
 Usage::
 
-    from mypy_boto3.ec2_instance_connect.type_defs import SendSSHPublicKeyResponseTypeDef
+    ```python
+    from mypy_boto3_ec2_instance_connect.type_defs import SendSSHPublicKeyResponseTypeDef
 
     data: SendSSHPublicKeyResponseTypeDef = {...}
+    ```
 """
 import sys
 
